Introduction
---------------------------
This project was made as a solution to many complaints at my workplace about password requirements being too
difficult to conform to and many, many external blogposts about the different specifications of varying websites.
In response, I created a simple command line password generator that takes password requirements and creates a more
than secure password. It even copies the password to the user's clipboard!

Technologies
---------------------------
All that is used here is Python 3.9.

Setup
---------------------------
lorem ipsum